pydevDAG._attributes._edgetypes module — pydevDAG 1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »
- pydevDAG._attributes package »

# pydevDAG._attributes._edgetypes module

## pydevDAG._attributes._edgetypes

Types of graph edges.

class `pydevDAG._attributes._edgetypes.` `EdgeType`

  Bases: `pydevDAG._attributes._metaclasses.AttributeValue`

  Superclass of edge types.

class `pydevDAG._attributes._edgetypes.` `EdgeTypes`

  Bases: `pydevDAG._attributes._metaclasses.AttributeValues`

  Enumeration of edge types.

  `CONGRUENCE` = Congruence()
  `ENCLOSUREBAY` = EnclosureBay()
  `PARTITION` = Partition()
  `SLAVE` = Slave()
  `SPINDLE` = Spindle()
  classmethod `values`()

### Navigation

- index
- modules |
- next |
- previous |
- pydevDAG 1.0 documentation »
- pydevDAG »
- pydevDAG package »
- pydevDAG._attributes package »